#[repr(C)]pub struct ArrowArray {
pub length: i64,
pub null_count: i64,
pub offset: i64,
pub n_buffers: i64,
pub n_children: i64,
pub buffers: *mut *const c_void,
pub children: *mut *mut ArrowArray,
pub dictionary: *mut ArrowArray,
pub release: Option<unsafe extern "C" fn(array: *mut ArrowArray)>,
pub private_data: *mut c_void,
}Expand description
ArrowArray C Data Interface: array (columnar data).
See: https://arrow.apache.org/docs/format/CDataInterface.html#the-arrowarray-structure
Ownership: This type has no Drop impl. Callers must invoke the
release callback (if Some) before dropping to free resources.
Fields
length: i64null_count: i64offset: i64n_buffers: i64n_children: i64buffers: *mut *const c_voidchildren: *mut *mut ArrowArraydictionary: *mut ArrowArrayrelease: Option<unsafe extern "C" fn(array: *mut ArrowArray)>private_data: *mut c_voidImplementations
Sourceimpl ArrowArray
impl ArrowArray
Sourcepub fn is_released(&self) -> bool
pub fn is_released(&self) -> bool
Whether this array has been released (release callback is None).
Sourcepub unsafe fn from_raw<T>(ptr: &T) -> &Self
pub unsafe fn from_raw<T>(ptr: &T) -> &Self
Borrow a foreign C Data Interface array as ours (zero-copy).
Safety
T must have the Arrow C Data Interface ArrowArray memory layout.
Sourcepub unsafe fn from_raw_mut<T>(ptr: &mut T) -> &mut Self
pub unsafe fn from_raw_mut<T>(ptr: &mut T) -> &mut Self
Mutably borrow a foreign C Data Interface array as ours (zero-copy).
Safety
T must have the Arrow C Data Interface ArrowArray memory layout.
Sourcepub unsafe fn as_raw<T>(&self) -> &T
pub unsafe fn as_raw<T>(&self) -> &T
Borrow ours as a foreign C Data Interface array type (zero-copy).
Safety
T must have the Arrow C Data Interface ArrowArray memory layout.
Sourcepub unsafe fn from_owned<T>(val: T) -> Self
pub unsafe fn from_owned<T>(val: T) -> Self
Take ownership of a foreign C Data Interface array.
Safety
Tmust have the Arrow C Data InterfaceArrowArraymemory layout.- Ownership transfers — the caller must not use or drop the original.
Sourcepub unsafe fn into_owned<T>(self) -> T
pub unsafe fn into_owned<T>(self) -> T
Convert into a foreign C Data Interface array type.
Safety
Tmust have the Arrow C Data InterfaceArrowArraymemory layout.- Ownership transfers — the caller must not use or drop the original.