ArrowSchema

Struct ArrowSchema 

#[repr(C)]
pub struct ArrowSchema { pub format: *const c_char, pub name: *const c_char, pub metadata: *const c_char, pub flags: i64, pub n_children: i64, pub children: *mut *mut ArrowSchema, pub dictionary: *mut ArrowSchema, pub release: Option<unsafe extern "C" fn(schema: *mut ArrowSchema)>, pub private_data: *mut c_void, }
ArrowSchema C Data Interface.

See: https://arrow.apache.org/docs/format/CDataInterface.html#the-arrowschema-structure

Ownership: This type has no Drop impl. Callers must invoke the release callback (if Some) before dropping to free resources.

Fields

format: *const c_charname: *const c_charmetadata: *const c_charflags: i64n_children: i64children: *mut *mut ArrowSchemadictionary: *mut ArrowSchemarelease: Option<unsafe extern "C" fn(schema: *mut ArrowSchema)>private_data: *mut c_void

Implementations

Source

impl ArrowSchema

pub fn empty() -> Self

Create an empty (released) schema.

pub fn is_released(&self) -> bool

Whether this schema has been released (release callback is None).

pub unsafe fn from_raw<T>(ptr: &T) -> &Self

Borrow a foreign C Data Interface schema as ours (zero-copy).

Safety

T must have the Arrow C Data Interface ArrowSchema memory layout.

pub unsafe fn from_raw_mut<T>(ptr: &mut T) -> &mut Self

Mutably borrow a foreign C Data Interface schema as ours (zero-copy).

Safety

T must have the Arrow C Data Interface ArrowSchema memory layout.

pub unsafe fn as_raw<T>(&self) -> &T

Borrow ours as a foreign C Data Interface schema type (zero-copy).

Safety

T must have the Arrow C Data Interface ArrowSchema memory layout.

pub unsafe fn from_owned<T>(val: T) -> Self

Take ownership of a foreign C Data Interface schema.

Safety
  • T must have the Arrow C Data Interface ArrowSchema memory layout.
  • Ownership transfers — the caller must not use or drop the original.
pub unsafe fn into_owned<T>(self) -> T

Convert into a foreign C Data Interface schema type.

Safety
  • T must have the Arrow C Data Interface ArrowSchema memory layout.
  • Ownership transfers — the caller must not use or drop the original.